==> nextcloud-10.0.2.tar.bz2: nextcloud/apps/files/l10n/nl.js <==
OC.L10N.register(
    "files",
    {
    "Storage is temporarily not available" : "Opslag is tijdelijk niet beschikbaar",
    "Storage invalid" : "Opslag ongeldig",
    "Unknown error" : "Onbekende fout",
    "Files" : "Bestanden",
    "All files" : "Alle bestanden",
    "Recent" : "Recent",
    "File could not be found" : "Bestand kon niet worden gevonden",
    "Home" : "Thuis",
    "Close" : "Sluiten",
    "Favorites" : "Favorieten",
    "Could not create folder \"{dir}\"" : "Kon map \"{dir}\" niet aanmaken",
    "Upload cancelled." : "Uploaden geannuleerd.",
    "Unable to upload {filename} as it is a directory or has 0 bytes" : "Kan {filename} niet uploaden omdat het een map is of 0 bytes groot is",
    "Not enough free space, you are uploading {size1} but only {size2} is left" : "Niet genoeg vrije ruimte. Je uploadt {size1}, maar er is slechts {size2} beschikbaar",
    "Target folder \"{dir}\" does not exist any more" : "Doelmap \"{dir}\" bestaat niet meer",
    "Not enough free space" : "Onvoldoende vrije ruimte",
    "Uploading..." : "Uploaden...",
    "..." : "...",
    "{hours}:{minutes}:{seconds} hour{plural_s} left" : "{hours}:{minutes}:{seconds} uur{plural_s} over",
    "{hours}:{minutes}h" : "{hours}:{minutes}h",
    "{minutes}:{seconds} minute{plural_s} left" : "{minutes}:{seconds} minuten{plural_s} over",
    "{minutes}:{seconds}m" : "{minutes}:{seconds}m",
    "{seconds} second{plural_s} left" : "{seconds} seconden{plural_s} over",
    "{seconds}s" : "{seconds}en",
    "Any moment now..." : "Heel snel nu...",
    "Soon..." : "Binnenkort...",
    "{loadedSize} of {totalSize} ({bitrate})" : "{loadedSize} van {totalSize} ({bitrate})",
    "File upload is in progress. Leaving the page now will cancel the upload." : "Bestandsupload is bezig. Wanneer de pagina nu verlaten wordt, stopt de upload.",
    "Actions" : "Acties",
    "Download" : "Downloaden",
    "Rename" : "Naam wijzigen",
    "Move" : "Verplaatsen",
    "Target folder" : "Doelmap",
    "Delete" : "Verwijderen",
    "Disconnect storage" : "Verbinding met opslag verbreken",
    "Unshare" : "Stop met delen",
    "Details" : "Details",
    "Select" : "Selecteer",
    "Pending" : "In behandeling",
    "Unable to determine date" : "Kon datum niet vaststellen",
    "This operation is forbidden" : "Deze taak is verboden",
    "This directory is unavailable, please check the logs or contact the administrator" : "Deze map is niet beschikbaar. Verifieer de logs of neem contact op met de beheerder",
    "Could not move \"{file}\", target exists" : "Kon \"{file}\" niet verplaatsen, doel bestaat al",
    "Could not move \"{file}\"" : "Kon \"{file}\" niet verplaatsen",
    "{newName} already exists" : "{newName} bestaat al",
    "Could not rename \"{fileName}\", it does not exist any more" : "Kon \"{fileName}\" niet hernoemen, het bestaat niet meer",
    "The name \"{targetName}\" is already used in the folder \"{dir}\". Please choose a different name." : "De naam \"{targetName}\" bestaat al in map \"{dir}\". Kies een andere naam.",
    "Could not rename \"{fileName}\"" : "Kon \"{fileName}\" niet hernoemen",
    "Could not create file \"{file}\"" : "Kon \"{file}\" niet aanmaken",
    "Could not create file \"{file}\" because it already exists" : "Kon \"{file}\" niet aanmaken, omdat het al bestaat",
    "Could not create folder \"{dir}\" because it already exists" : "Kon map \"{dir}\" niet aanmaken, omdat die al bestaat",
    "Error deleting file \"{fileName}\"." : "Fout bij verwijderen bestand \"{fileName}\".",
    "No search results in other folders for '{tag}{filter}{endtag}'" : "Geen zoekresultaten voor '{tag}{filter}{endtag}' in andere mappen",
    "Name" : "Naam",
    "Size" : "Grootte",
    "Modified" : "Aangepast",
    "_%n folder_::_%n folders_" : ["%n map","%n mappen"],
    "_%n file_::_%n files_" : ["%n bestand","%n bestanden"],
    "{dirs} and {files}" : "{dirs} en {files}",
    "_including %n hidden_::_including %n hidden_" : ["inclusief %n verborgen","inclusief %n verborgen"],
    "You don’t have permission to upload or create files here" : "Je hebt geen toestemming om hier te uploaden of bestanden te maken",
    "_Uploading %n file_::_Uploading %n files_" : ["%n bestand aan het uploaden","%n bestanden aan het uploaden"],
    "New" : "Nieuw",
    "\"{name}\" is an invalid file name." : "\"{name}\" is een ongeldige bestandsnaam.",
    "File name cannot be empty." : "Bestandsnaam kan niet leeg zijn.",
    "Storage of {owner} is full, files can not be updated or synced anymore!" : "Opslagruimte van {owner} zit vol, bestanden kunnen niet meer worden ge-upload of gesynchroniseerd!",
    "Your storage is full, files can not be updated or synced anymore!" : "Je opslagruimte zit vol. Bestanden kunnen niet meer worden gewijzigd of gesynchroniseerd!",
    "Storage of {owner} is almost full ({usedSpacePercent}%)" : "Opslagruimte van {owner} zit bijna vol ({usedSpacePercent}%)",
    "Your storage is almost full ({usedSpacePercent}%)" : "Je opslagruimte zit bijna vol ({usedSpacePercent}%)",
    "_matches '{filter}'_::_match '{filter}'_" : ["komt overeen met '{filter}'","komen overeen met '{filter}'"],
    "View in folder" : "Bekijken in map",
    "Path" : "Pad",
    "_%n byte_::_%n bytes_" : ["%n byte","%n bytes"],
    "Favorited" : "Favoriet",
    "Favorite" : "Favoriet",
    "Copy local link" : "Kopiëren lokale link",
    "Folder" : "Map",
    "New folder" : "Nieuwe map",
    "Upload" : "Uploaden",
    "An error occurred while trying to update the tags" : "Er trad een fout op bij uw poging de markeringen bij te werken",
    "Added to favorites" : "Toevoegen aan favorieten",
    "Removed from favorites" : "Verwijderen uit favorieten",
    "You added {file} to your favorites" : "Je voegde {file} toe aan favorieten",
    "You removed {file} from your favorites" : "Je verwijderde {file} van favorieten",
    "File changes" : "Bestandswijzigingen",
    "Created by {user}" : "Gecreëerd door {user}",
    "Changed by {user}" : "Gewijzigd door {user}",
    "Deleted by {user}" : "Verwijderd door {user}",
    "Restored by {user}" : "Hersteld door {user}",
    "Renamed by {user}" : "Hernoemd door {user}",
    "Moved by {user}" : "Verplaatst door {user}",
    "You created {file}" : "Je creëerde {file}",
    "{user} created {file}" : "{user} creëerde {file}",
    "{file} was created in a public folder" : "{file} werd gecreëerd in een openbare map",
    "You changed {file}" : "Je wijzigde {file}",
    "{user} changed {file}" : "{user} wijzigde {file}",
    "You deleted {file}" : "Je verwijderde {file}",
    "{user} deleted {file}" : "{user} verwijderde {file}",
    "You restored {file}" : "Je herstelde {file}",
    "{user} restored {file}" : "{user} herstelde {file}",
    "You renamed {oldfile} to {newfile}" : "Je hernoemde {oldfile} naar {newfile}",
    "{user} renamed {oldfile} to {newfile}" : "{user} hernoemde {oldfile} naar {newfile}",
    "You moved {oldfile} to {newfile}" : "Je verplaatste {oldfile} naar {newfile}",
    "{user} moved {oldfile} to {newfile}" : "{user} verplaatste {oldfile} naar {newfile}",
    "A file has been added to or removed from your <strong>favorites</strong>" : "Een bestand werd toegevoegd of verwijderd van je <strong>favorieten</strong>",
    "A file or folder has been <strong>changed</strong> or <strong>renamed</strong>" : "Een bestand of map is <strong>gewijzigd</strong> of <strong>hernoemd</strong>",
    "A new file or folder has been <strong>created</strong>" : "Een nieuw bestand of map is <strong>aangemaakt</strong>",
    "A new file or folder has been <strong>deleted</strong>" : "Een nieuw bestand of nieuwe map is <strong>verwijderd</strong>",
    "Limit notifications about creation and changes to your <strong>favorite files</strong> <em>(Stream only)</em>" : "Beperk meldingen over aanmaken en wijzigen aan je <strong>favoriete bestanden</strong> <em>(Alleen stream)</em>",
    "A new file or folder has been <strong>restored</strong>" : "Een nieuw bestand of een nieuwe map is <strong>hersteld</strong>",
    "Upload (max. %s)" : "Upload (max. %s)",
    "File handling" : "Bestand",
    "Maximum upload size" : "Maximale bestandsgrootte voor uploads",
    "max. possible: " : "max. mogelijk: ",
    "Save" : "Bewaren",
    "With PHP-FPM it might take 5 minutes for changes to be applied." : "Met PHP-FPM kan het 5 minuten duren voordat wijzigingen zijn doorgevoerd.",
    "Missing permissions to edit from here." : "Ontbrekende rechten om vanaf hier te bewerken.",
    "Settings" : "Instellingen",
    "Show hidden files" : "Tonen verborgen bestanden",
    "WebDAV" : "WebDAV",
    "Use this address to <a href=\"%s\" target=\"_blank\" rel=\"noreferrer\">access your Files via WebDAV</a>" : "Gebruik deze link <a href=\"%s\" target=\"_blank\" rel=\"noreferrer\">om je bestanden via WebDAV te benaderen</a>",
    "No files in here" : "Hier geen bestanden",
    "Upload some content or sync with your devices!" : "Upload bestanden of synchroniseer met je apparaten!",
    "No entries found in this folder" : "Niets",
    "Select all" : "Alles selecteren",
    "Upload too large" : "Upload is te groot",
    "The files you are trying to upload exceed the maximum size for file uploads on this server." : "De bestanden die je probeert te uploaden zijn groter dan de maximaal toegestane  bestandsgrootte voor deze server.",
    "No favorites" : "Geen favorieten",
    "Files and folders you mark as favorite will show up here" : "Bestanden en mappen die je als favoriet aanmerkt, worden hier getoond",
    "Shared with you" : "Gedeeld met jou",
    "Shared with others" : "Gedeeld met anderen",
    "Shared by link" : "Gedeeld via link",
    "Tags" : "Tags",
    "Deleted files" : "Verwijderde bestanden",
    "Text file" : "Tekstbestand",
    "New text file.txt" : "Nieuw tekstbestand.txt",
    "Storage not available" : "Opslag niet beschikbaar",
    "Unable to set upload directory." : "Kan uploadmap niet instellen.",
    "Invalid Token" : "Ongeldig Token",
    "No file was uploaded. Unknown error" : "Er was geen bestand geladen.  Onbekende fout",
    "There is no error, the file uploaded with success" : "Het bestand is succesvol geüpload.",
    "The uploaded file exceeds the upload_max_filesize directive in php.ini: " : "Het geüploade bestand overschrijdt de upload_max_filesize optie in php.ini:",
    "The uploaded file exceeds the MAX_FILE_SIZE directive that was specified in the HTML form" : "Het bestand overschrijdt de MAX_FILE_SIZE instelling die is opgegeven in het HTML formulier",
    "The uploaded file was only partially uploaded" : "Het bestand is slechts gedeeltelijk geüpload",
    "No file was uploaded" : "Er is geen bestand geüpload",
    "Missing a temporary folder" : "Er ontbreekt een tijdelijke map",
    "Failed to write to disk" : "Schrijven naar schijf mislukt",
    "Not enough storage available" : "Niet genoeg opslagruimte beschikbaar",
    "The target folder has been moved or deleted." : "De doelmap is verplaatst of verwijderd.",
    "Upload failed. Could not find uploaded file" : "Upload mislukt. Kon geüploade bestand niet vinden",
    "Upload failed. Could not get file info." : "Upload mislukt. Kon geen bestandsinfo krijgen.",
    "Invalid directory." : "Ongeldige directory.",
    "Total file size {size1} exceeds upload limit {size2}" : "Totale bestandsgrootte {size1} groter dan uploadlimiet {size2}",
    "Error uploading file \"{fileName}\": {message}" : "Fout tijdens het uploaden van bestand \"{fileName}\": {message}",
    "Could not get result from server." : "Kon het resultaat van de server niet terugkrijgen.",
    "No entries in this folder match '{filter}'" : "Niets in deze map komt overeen met '{filter}'",
    "Local link" : "Lokale link",
    "{newname} already exists" : "{newname} bestaat al",
    "A file or folder has been <strong>changed</strong>" : "Een bestand of map is <strong>gewijzigd</strong>",
    "A file or folder has been <strong>deleted</strong>" : "Een bestand of map is <strong>verwijderd</strong>",
    "A file or folder has been <strong>restored</strong>" : "Een bestand of een map is <strong>hersteld</strong>",
    "You created %1$s" : "Gecreëerd: %1$s",
    "%2$s created %1$s" : "%2$s creëerde %1$s",
    "%1$s was created in a public folder" : "%1$s werd gecreëerd in een openbare map",
    "You changed %1$s" : "Gewijzigd: %1$s",
    "%2$s changed %1$s" : "%2$s wijzigde %1$s",
    "You deleted %1$s" : "Je verwijderde: %1$s",
    "%2$s deleted %1$s" : "%2$s verwijderde %1$s",
    "You restored %1$s" : "Hersteld: %1$s",
    "%2$s restored %1$s" : "%2$s herstelde %1$s",
    "Changed by %2$s" : "Gewijzigd door %2$s",
    "Deleted by %2$s" : "Verwijderd door %2$s",
    "Restored by %2$s" : "Hersteld door %2$s",
    "Use this address to <a href=\"%s\" target=\"_blank\">access your Files via WebDAV</a>" : "Gebruik deze link <a href=\"%s\" target=\"_blank\" rel=\"noreferrer\">om je bestanden via WebDAV te benaderen</a>",
    "Cancel upload" : "Upload annuleren"
},
"nplurals=2; plural=(n != 1);");

==> nextcloud-15.0.14.tar.bz2: nextcloud/apps/files/l10n/nl.js <==
OC.L10N.register(
    "files",
    {
    "Storage is temporarily not available" : "Opslag is tijdelijk niet beschikbaar",
    "Storage invalid" : "Opslag ongeldig",
    "Unknown error" : "Onbekende fout",
    "All files" : "Alle bestanden",
    "Recent" : "Recent",
    "Favorites" : "Favorieten",
    "File could not be found" : "Bestand kon niet worden gevonden",
    "Move or copy" : "Verplaats of kopieer",
    "Download" : "Downloaden",
    "Delete" : "Verwijderen",
    "Home" : "Thuis",
    "Close" : "Sluiten",
    "Could not create folder \"{dir}\"" : "Kon map \"{dir}\" niet aanmaken",
    "This will stop your current uploads." : "Dit beëindigt onderhanden uploads",
    "Upload cancelled." : "Uploaden geannuleerd.",
    "Processing files …" : "Verwerken bestanden ...",
    "…" : "...",
    "Unable to upload {filename} as it is a directory or has 0 bytes" : "Kan {filename} niet uploaden omdat het een map is of 0 bytes groot is",
    "Not enough free space, you are uploading {size1} but only {size2} is left" : "Niet genoeg vrije ruimte. Je uploadt {size1}, maar er is slechts {size2} beschikbaar",
    "Target folder \"{dir}\" does not exist any more" : "Doelmap \"{dir}\" bestaat niet meer",
    "Not enough free space" : "Onvoldoende vrije ruimte",
    "An unknown error has occurred" : "Er trad een onbekende fout op.",
    "Uploading …" : "Uploaden …",
    "{loadedSize} of {totalSize} ({bitrate})" : "{loadedSize} van {totalSize} ({bitrate})",
    "Uploading that item is not supported" : "Uploaden van dat object is niet ondersteund",
    "Target folder does not exist any more" : "Doelmap bestaat niet meer",
    "Error when assembling chunks, status code {status}" : "Fout tijdens samenvoegen van brokken, status code {status}",
    "Actions" : "Acties",
    "Rename" : "Naam wijzigen",
    "Copy" : "Kopiëren",
    "Choose target folder" : "Kies doelmap…",
    "Open" : "Openen",
    "Delete file" : "Verwijderen bestand",
    "Delete folder" : "Verwijderen map",
    "Disconnect storage" : "Verbinding met opslag verbreken",
    "Unshare" : "Stop met delen",
    "Could not load info for file \"{file}\"" : "Kon geen informatie laden voor bestand \"{file}\"",
    "Files" : "Bestanden",
    "Details" : "Details",
    "Select" : "Selecteer",
    "Pending" : "In behandeling",
    "Unable to determine date" : "Kon datum niet vaststellen",
    "This operation is forbidden" : "Deze taak is verboden",
    "This directory is unavailable, please check the logs or contact the administrator" : "Deze map is niet beschikbaar. Verifieer de logs of neem contact op met de beheerder",
    "Could not move \"{file}\", target exists" : "Kon \"{file}\" niet verplaatsen, doel bestaat al",
    "Could not move \"{file}\"" : "Kon \"{file}\" niet verplaatsen",
    "copy" : "kopiëren",
    "Could not copy \"{file}\", target exists" : "Kon \"{bestand}\" niet kopiëren, het doel bestaat",
    "Could not copy \"{file}\"" : "Kon \"{file}\" niet kopiëren",
    "Copied {origin} inside {destination}" : "Kopieerde {oorsprong} binnen {bestemming}",
    "Copied {origin} and {nbfiles} other files inside {destination}" : "Heeft {andere} en {nbfiles} andere bestanden in {destination} gekopieerd",
    "{newName} already exists" : "{newName} bestaat al",
    "Could not rename \"{fileName}\", it does not exist any more" : "Kon \"{fileName}\" niet hernoemen, het bestaat niet meer",
    "The name \"{targetName}\" is already used in the folder \"{dir}\". Please choose a different name." : "De naam \"{targetName}\" bestaat al in map \"{dir}\". Kies een andere naam.",
    "Could not rename \"{fileName}\"" : "Kon \"{fileName}\" niet hernoemen",
    "Could not create file \"{file}\"" : "Kon \"{file}\" niet aanmaken",
    "Could not create file \"{file}\" because it already exists" : "Kon \"{file}\" niet aanmaken, omdat het al bestaat",
    "Could not create folder \"{dir}\" because it already exists" : "Kon map \"{dir}\" niet aanmaken, omdat die al bestaat",
    "Error deleting file \"{fileName}\"." : "Fout bij verwijderen bestand \"{fileName}\".",
    "No search results in other folders for {tag}{filter}{endtag}" : "Geen zoekresultaten voor {tag}{filter}{endtag} in andere mappen",
    "Name" : "Naam",
    "Size" : "Grootte",
    "Modified" : "Aangepast",
    "_%n folder_::_%n folders_" : ["%n map","%n mappen"],
    "_%n file_::_%n files_" : ["%n bestand","%n bestanden"],
    "{dirs} and {files}" : "{dirs} en {files}",
    "_including %n hidden_::_including %n hidden_" : ["inclusief %n verborgen","inclusief %n verborgen"],
    "You don’t have permission to upload or create files here" : "Je hebt geen toestemming om hier te uploaden of bestanden te maken",
    "_Uploading %n file_::_Uploading %n files_" : ["%n bestand aan het uploaden","%n bestanden aan het uploaden"],
    "New" : "Nieuw",
    "Select file range" : "Kies een reeks bestanden",
    "{used} of {quota} used" : "{used} van {quota} gebruikt",
    "{used} used" : "{used} gebruikt",
    "\"{name}\" is an invalid file name." : "\"{name}\" is een ongeldige bestandsnaam.",
    "File name cannot be empty." : "Bestandsnaam kan niet leeg zijn.",
    "\"/\" is not allowed inside a file name." : "\"/\" is niet toegestaan binnen een bestandsnaam.",
    "\"{name}\" is not an allowed filetype" : "\"{name}\" bestandstype is een niet toegestaande",
    "Storage of {owner} is full, files can not be updated or synced anymore!" : "Opslagruimte van {owner} zit vol, bestanden kunnen niet meer worden geüpload of gesynchroniseerd!",
    "Your storage is full, files can not be updated or synced anymore!" : "Je opslagruimte zit vol. Bestanden kunnen niet meer worden gewijzigd of gesynchroniseerd!",
    "Storage of {owner} is almost full ({usedSpacePercent}%)" : "Opslagruimte van {owner} zit bijna vol ({usedSpacePercent}%)",
    "Your storage is almost full ({usedSpacePercent}%)" : "Je opslagruimte zit bijna vol ({usedSpacePercent}%)",
    "_matches '{filter}'_::_match '{filter}'_" : ["komt overeen met '{filter}'","komen overeen met '{filter}'"],
    "View in folder" : "Bekijken in map",
    "Copied!" : "Gekopieerd!",
    "Copy direct link (only works for users who have access to this file/folder)" : "Kopieer de link direct (werkt alleen voor gebruikers met toegang tot map/bestand)",
    "Path" : "Pad",
    "_%n byte_::_%n bytes_" : ["%n byte","%n bytes"],
    "Favorited" : "Favoriet",
    "Favorite" : "Favoriet",
    "You can only favorite a single file or folder at a time" : "Je kunt maar één bestand of map tegelijk favoriet maken",
    "New folder" : "Nieuwe map",
    "Upload file" : "Bestand uploaden",
    "Not favorited" : "Niet in favorieten",
    "Remove from favorites" : "Verwijderen uit favorieten",
    "Add to favorites" : "Aan favorieten toevoegen",
    "An error occurred while trying to update the tags" : "Er trad een fout op bij je poging om de tags bij te werken",
    "Added to favorites" : "Toevoegen aan favorieten",
    "Removed from favorites" : "Verwijderen uit favorieten",
    "You added {file} to your favorites" : "Je voegde {file} toe aan favorieten",
    "You removed {file} from your favorites" : "Je verwijderde {file} uit je favorieten",
    "File changes" : "Bestandswijzigingen",
    "Created by {user}" : "Gecreëerd door {user}",
    "Changed by {user}" : "Gewijzigd door {user}",
    "Deleted by {user}" : "Verwijderd door {user}",
    "Restored by {user}" : "Hersteld door {user}",
    "Renamed by {user}" : "Hernoemd door {user}",
    "Moved by {user}" : "Verplaatst door {user}",
    "\"remote user\"" : "\"externe gebruiker\"",
    "You created {file}" : "Je creëerde {file}",
    "You created an encrypted file in {file}" : "Je creëerde een versleuteld bestand in {file}",
    "{user} created {file}" : "{user} creëerde {file}",
    "{user} created an encrypted file in {file}" : "{user} creëerde een versleuteld bestand in {file}",
    "{file} was created in a public folder" : "{file} werd gecreëerd in een openbare map",
    "You changed {file}" : "Je wijzigde {file}",
    "You changed an encrypted file in {file}" : "Je wijzigde een versleuteld bestand in {file}",
    "{user} changed {file}" : "{user} wijzigde {file}",
    "{user} changed an encrypted file in {file}" : "{user} heeft een versleuteteld bestand veranderd in {file}",
    "You deleted {file}" : "Je verwijderde {file}",
    "You deleted an encrypted file in {file}" : "Je hebt een versleuteld bestand gewist in {file}",
    "{user} deleted {file}" : "{user} verwijderde {file}",
    "{user} deleted an encrypted file in {file}" : "{user} heeft een versleuteld bestand gewist in {file}",
    "You restored {file}" : "Je herstelde {file}",
    "{user} restored {file}" : "{user} herstelde {file}",
    "You renamed {oldfile} to {newfile}" : "Je hernoemde {oldfile} naar {newfile}",
    "{user} renamed {oldfile} to {newfile}" : "{user} hernoemde {oldfile} naar {newfile}",
    "You moved {oldfile} to {newfile}" : "Je verplaatste {oldfile} naar {newfile}",
    "{user} moved {oldfile} to {newfile}" : "{user} verplaatste {oldfile} naar {newfile}",
    "A file has been added to or removed from your <strong>favorites</strong>" : "Een bestand werd toegevoegd of verwijderd van je <strong>favorieten</strong>",
    "A file or folder has been <strong>changed</strong> or <strong>renamed</strong>" : "Een bestand of map is <strong>gewijzigd</strong> of <strong>hernoemd</strong>",
    "A new file or folder has been <strong>created</strong>" : "Een nieuw bestand of map is <strong>aangemaakt</strong>",
    "A file or folder has been <strong>deleted</strong>" : "Een bestand of map is <strong>verwijderd</strong>",
    "Limit notifications about creation and changes to your <strong>favorite files</strong> <em>(Stream only)</em>" : "Beperk meldingen over aanmaken en wijzigen aan je <strong>favoriete bestanden</strong> <em>(Alleen stream)</em>",
    "A file or folder has been <strong>restored</strong>" : "Een bestand of een map is <strong>hersteld</strong>",
    "Unlimited" : "Ongelimiteerd",
    "Upload (max. %s)" : "Upload (max. %s)",
    "File Management" : "Bestandsbeheer",
    "Error while loading the file data" : "Fout bij het lezen van de bestandsgegevens",
    "Unable to change the favourite state of the file" : "Niet mogelijk om voorkeurtoestand van het bestand te wijzigen",
    "%s used" : "%s gebruikt",
    "%s%% of %s used" : "%s%% van %s gebruikt",
    "%1$s of %2$s used" : "%1$s van %2$s gebruikt",
    "Settings" : "Instellingen",
    "Show hidden files" : "Verborgen bestanden tonen",
    "WebDAV" : "WebDAV",
    "Use this address to <a href=\"%s\" target=\"_blank\" rel=\"noreferrer noopener\">access your Files via WebDAV</a>" : "Gebruik deze link <a href=\"%s\" target=\"_blank\" rel=\"noreferrer noopener\">om je bestanden te benaderen via WebDAV</a>",
    "Toggle grid view" : "Omschakelen roosterweergave",
    "No files in here" : "Hier geen bestanden",
    "Upload some content or sync with your devices!" : "Upload je inhoud of synchroniseer met je apparaten!",
    "No entries found in this folder" : "Niets",
    "Select all" : "Alles selecteren",
    "Upload too large" : "Upload is te groot",
    "The files you are trying to upload exceed the maximum size for file uploads on this server." : "De bestanden die je probeert te uploaden zijn groter dan de maximaal toegestane  bestandsgrootte voor deze server.",
    "No favorites yet" : "Nog geen favorieten",
    "Files and folders you mark as favorite will show up here" : "Bestanden en mappen die je als favoriet aanmerkt, worden hier getoond",
    "Tags" : "Tags",
    "Deleted files" : "Verwijderde bestanden",
    "Shares" : "Shares",
    "Shared with others" : "Gedeeld met anderen",
    "Shared with you" : "Gedeeld met jou",
    "Shared by link" : "Gedeeld via link",
    "Deleted shares" : "Verwijderde shares",
    "Text file" : "Tekstbestand",
    "New text file.txt" : "Nieuw tekstbestand.txt",
    "File handling" : "Bestand afhandeling",
    "Maximum upload size" : "Maximale bestandsgrootte voor uploads",
    "max. possible: " : "max. mogelijk: ",
    "Save" : "Bewaren",
    "With PHP-FPM it might take 5 minutes for changes to be applied." : "Met PHP-FPM kan het 5 minuten duren voordat wijzigingen zijn doorgevoerd.",
    "Missing permissions to edit from here." : "Ontbrekende rechten om vanaf hier te bewerken.",
    "Cancel upload" : "Stop upload",
    "%s of %s used" : "%s van %s gebruikt",
    "%1$s%% of %2$s used" : "%1$s%% van %2$s gebruikt"
},
"nplurals=2; plural=(n != 1);");
